@@ -14,9 +14,9 @@
 #          (1)Output list data
 # v0.1.0 : 2021/05/024 
 #          (1)Output DataFrame
-# v0.1.1 : 2021/05/026 info modify
+# v0.1.1 : 2021/05/26
+# v0.1.2 : 2021/05/26 bug fix
 #
-
 import serial
 import time
 import struct
@@ -75,7 +75,7 @@ class LpdFDS:
 		print("(jb)Hardware: IWR-6843")
 		print("(jb)Firmware: lpd-I471")
 		print("(jb)UART Baud Rate:921600")
-		print("Output: V6,V7,V8,V9 data: RAW Data or DataFrame")
+		print("Output: V6,V7,V8,V9 data:(RAW)")
 		
 	def useDebug(self,falseTrue):
 		self.dbg = falseTrue
@@ -275,7 +275,7 @@ class LpdFDS:
 					try:
 						ttype,self.tlvLength = struct.unpack('2I', sbuf)
 						if disp == True:
-							print("(TL)--tlvNum:{:d}: tlvCount({:d})-------ttype:tlvLength:v{:d}:{:d}".format(self.hdr.numTLVs,tlvCount,ttype,self.tlvLength
+							print("(TL)--tlvNum:{:d}: tlvCount({:d})-------ttype:tlvLength:v{:d}:{:d}".format(self.hdr.numTLVs,tlvCount,ttype,self.tlvLength))
 							
 						if ttype not in typeList or self.tlvLength > 10000:
 							if self.dbg == True:
